==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/desMarkers.R <==
# descriptive statistics for markers

HWPvalFun.sim<-function(marker, geneSetObj, founderOnly=FALSE, simulate.p.value=FALSE,B=1000, ...)
{
  tmp<-HWE.chisq(geneSetObj, marker=marker, simulate.p.value=simulate.p.value,
                 B=B, founderOnly=founderOnly, ...)
  p.value<-tmp$p.value
  return(p.value)
}

HWPvalFun.exact<-function(marker, geneSetObj, founderOnly=FALSE)
{
  tmp<-HWE.exact(geneSetObj, marker=marker, founderOnly=founderOnly)
  p.value<-tmp$p.value
  return(p.value)
}


desMarkers<-function(geneSetObj, 
                     founderOnly=TRUE, 
                     thrsh=0.05,
                     HWE.method=c("simulate","exact"),
                     simulate.p.value=FALSE, 
                     B=10000,
                     markerThrsh=100,
                     maxDist=5,
                     LDmeasure="r2",
                     plot=TRUE,
                     ...)
{
  mNames<-markerNames(geneSetObj)
  nmarkers<-length(mNames)

  HWE.method <- match.arg(HWE.method, choices=c("simulate", "exact"))
  if(HWE.method=="simulate")
  { pvals<-tapply(1:nmarkers, 1:nmarkers, HWPvalFun.sim, geneSetObj=geneSetObj,
         founderOnly=founderOnly, simulate.p.value=simulate.p.value,B=B,...)
  }
  else if(HWE.method=="exact")
  { pvals<-tapply(1:nmarkers, 1:nmarkers, HWPvalFun.exact, geneSetObj=geneSetObj, founderOnly=founderOnly)
  }
  else
  { stop("Unkown HWE method: ", HWE.method) }

  Rating<-rep(0, nmarkers)
  Rating[pvals>thrsh]<-1 # pass HWE test

  tmp<-alleleSummary(geneSetObj, founderOnly=founderOnly, ...)

  # get position info
  t1<-tmp[[1]][,3]
  t2<-matrix(t1, ncol=4, byrow=T)
  Position<-t2[,1]

  # get MAF
  t1<-tmp[[1]][,7]
  t2<-matrix(t1, ncol=4, byrow=T)
  t3<-t2[,1:2]
  aFreq<-apply(t3, 2, as.numeric)
  MAF<-apply(aFreq, 1, min)

  # get PredHET -- marker's predicted heterozygosity (i.e., 2*MAF*(1-MAF))
  PredHET<-2*MAF*(1-MAF)

  # get ObsHET and %Geno
  tmp<-genotypeSummary(geneSetObj, founderOnly=founderOnly, ...)
  t1<-tmp[[1]][,6]
  t2<-matrix(t1, ncol=5, byrow=T)
  t2<-t2[,1:4]
  t2<-apply(t2, 2, as.numeric)
  countHET<-t2[,2]
  countNA<-t2[,4]
  countSum<-apply(t2, 1, sum)
  pGeno<-100*(1-countNA/countSum)

  # exclude genotypes containing missing allele
  countSum2<-apply(t2[,1:3], 1, sum) 
  ObsHET<-countHET/countSum2

  datFrame<-data.frame(Names=mNames, Position=Position, ObsHET=ObsHET, PredHET=PredHET, HWPval=pvals, pGeno=pGeno, MAF=MAF, Rating=Rating)

  if(founderOnly==TRUE)
  { geneSetObj<-founderGeneSet(geneSetObj) }

  # LDView
  
  if(!is.null(markerInfo(geneSetObj)$Position))
  {  posVec<-as.numeric(markerInfo(geneSetObj)$Position)
     posVec2<-posVec
  }  
  else
  {  posVec<-1:nmarkers 
     posVec2<-NULL
  }

  if(nmarkers<=markerThrsh)
  { ldMat<-LD(geneSetObj) }
  else {
    ldMat<-LDdist(geneSetObj, posVec=posVec, maxDist=maxDist) 
  }
  if(LDmeasure=="D'")
  { ldMat<-ldMat@"D'" }
  else { ldMat<-ldMat@"R^2" }

  diag(ldMat)<-1

  if(plot==TRUE)
  {
    LDViewObj<-LDView(t(ldMat), SNPloc=posVec2, labRow=mNames)
  }

  invisible(datFrame)
}

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/desMarkers.R <==
# descriptive statistics for markers

HWPvalFun.sim<-function(marker, geneSetObj, founderOnly=FALSE, simulate.p.value=FALSE,B=1000, ...)
{
  tmp<-HWE.chisq(geneSetObj, marker=marker, simulate.p.value=simulate.p.value,
                 B=B, founderOnly=founderOnly, ...)
  p.value<-tmp$p.value
  return(p.value)
}

HWPvalFun.exact<-function(marker, geneSetObj, founderOnly=FALSE)
{
  tmp<-HWE.exact(geneSetObj, marker=marker, founderOnly=founderOnly)
  p.value<-tmp$p.value
  return(p.value)
}


desMarkers<-function(geneSetObj, 
                     founderOnly=TRUE, 
                     thrsh=0.05,
                     HWE.method=c("simulate","exact"),
                     simulate.p.value=FALSE, 
                     B=10000,
                     markerThrsh=100,
                     maxDist=5,
                     LDmeasure="r2",
                     plot=TRUE,
                     ...)
{

  if(founderOnly==TRUE)
  { object<-founderGeneSet(object) }

  mNames<-markerNames(geneSetObj)
  nMarkers<-length(mNames)

  HWE.method <- match.arg(HWE.method, choices=c("simulate", "exact"))
  if(HWE.method=="simulate")
  { pvals<-tapply(1:nMarkers, 1:nMarkers, HWPvalFun.sim, geneSetObj=geneSetObj,
         founderOnly=founderOnly, simulate.p.value=simulate.p.value,B=B,...)
  }
  else if(HWE.method=="exact")
  { pvals<-tapply(1:nMarkers, 1:nMarkers, HWPvalFun.exact, geneSetObj=geneSetObj, founderOnly=founderOnly)
  }
  else
  { stop("Unkown HWE method: ", HWE.method) }

  Rating<-rep(0, nMarkers)
  Rating[pvals>thrsh]<-1 # pass HWE test

  tmp<-alleleSummary(geneSetObj,  ...)

  ## get position info
  #t1<-tmp[[1]][,3]
  #t2<-matrix(t1, ncol=4, byrow=T)
  #Position<-t2[,1]
  Position<-markerInfo(geneSetObj)$Position
  if(is.null(Position))
  { Position<-rep("?", nMarkers) }

  # get MAF
  t1<-tmp[[1]][,7]
  t2<-matrix(t1, ncol=4, byrow=T)
  t3<-t2[,1:2]
  aFreq<-apply(t3, 2, as.numeric)
  MAF<-apply(aFreq, 1, min)

  # get PredHET -- marker's predicted heterozygosity (i.e., 2*MAF*(1-MAF))
  PredHET<-2*MAF*(1-MAF)

  # get ObsHET and %Geno
  tmp<-genotypeSummary(geneSetObj, founderOnly=founderOnly, ...)
  t1<-tmp[[1]][,6]
  t2<-matrix(t1, ncol=5, byrow=T)
  t2<-t2[,1:4]
  t2<-apply(t2, 2, as.numeric)
  countHET<-t2[,2]
  countNA<-t2[,4]
  countSum<-apply(t2, 1, sum)
  pGeno<-100*(1-countNA/countSum)

  # exclude genotypes containing missing allele
  countSum2<-apply(t2[,1:3], 1, sum) 
  ObsHET<-countHET/countSum2

  datFrame<-data.frame(Names=mNames,
                       Position=Position,
                       ObsHET=ObsHET,
                       PredHET=PredHET,
                       HWPval=pvals,
                       pGeno=pGeno,
                       MAF=MAF,
                       Rating=Rating)

  if(founderOnly==TRUE)
  { geneSetObj<-founderGeneSet(geneSetObj) }

  # LDView
  
  if(!is.null(markerInfo(geneSetObj)$Position))
  {  posVec<-as.numeric(markerInfo(geneSetObj)$Position)
     posVec2<-posVec
  }  
  else
  {  posVec<-1:nMarkers 
     posVec2<-NULL
  }

  if(nMarkers<=markerThrsh)
  { ldMat<-LD(geneSetObj) }
  else {
    ldMat<-LDdist(geneSetObj, posVec=posVec, maxDist=maxDist) 
  }
  if(LDmeasure=="D'")
  { ldMat<-ldMat@"D'" }
  else { ldMat<-ldMat@"R^2" }

  diag(ldMat)<-1

  if(plot==TRUE)
  {
    LDViewObj<-LDView(t(ldMat), SNPloc=posVec2)
  }

  invisible(datFrame)
}
